Security Advisories (1)
CVE-2022-23935 (2022-01-25)

lib/Image/ExifTool.pm in ExifTool before 12.38 mishandles a $file =~ /\|$/ check, leading to command injection.

NAME

Image::ExifTool::Audible - Read meta information from Audible audio books

SYNOPSIS

This module is used by Image::ExifTool

DESCRIPTION

This module contains definitions required by Image::ExifTool to read meta information from Audible audio books.

AUTHOR

Copyright 2003-2021, Phil Harvey (philharvey66 at gmail.com)

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

REFERENCES

https://github.com/jteeuwen/audible
https://code.google.com/p/pyaudibletags/
http://wiki.multimedia.cx/index.php?title=Audible_Audio

SEE ALSO

"Audible Tags" in Image::ExifTool::TagNames, Image::ExifTool(3pm)